@@ -4,8 +4,8 @@ distributed under the Creative Commons Attribution-ShareAlike 3.0
 Unported License. */
 
 #include "ip-tools.h"
-int n_china_ips = 2560;
-ip_block_t china_ips[2560] = {
+int n_china_ips = 2784;
+ip_block_t china_ips[2784] = {
 {0x1000100,0x10003FF},
 {0x1000800,0x1000FFF},
 {0x1002000,0x1003FFF},
@@ -29,6 +29,71 @@ ip_block_t china_ips[2560] = {
 {0x1B40000,0x1B9FFFF},
 {0x1BC0000,0x1C7FFFF},
 {0x1CA0000,0x1CFFFFF},
+{0x50A4628,0x50A462B},
+{0x50A4650,0x50A4657},
+{0x50A47E9,0x50A47E9},
+{0x50A4850,0x50A485F},
+{0x50A4A28,0x50A4A9F},
+{0x50A4AC0,0x50A4ADF},
+{0x50A4BE0,0x50A4BEF},
+{0x50A4FF0,0x50A4FF7},
+{0x50A52A8,0x50A52AF},
+{0x50A5468,0x50A546F},
+{0x50A5508,0x50A550B},
+{0x50A5550,0x50A5557},
+{0x50A5560,0x50A5567},
+{0x50A5630,0x50A5637},
+{0x50A5648,0x50A564B},
+{0x50A56A0,0x50A56A7},
+{0x50A5702,0x50A5702},
+{0x50A5760,0x50A5767},
+{0x50A5780,0x50A5787},
+{0x50A57C0,0x50A57C1},
+{0x50A57D6,0x50A57D7},
+{0x50A57F4,0x50A57F6},
+{0x50A57FC,0x50A57FD},
+{0x50A58F0,0x50A58FF},
+{0x50A5AE8,0x50A5AEF},
+{0x50A6148,0x50A614B},
+{0x50A61A0,0x50A61A7},
+{0x50A68D8,0x50A68DF},
+{0x50A6B50,0x50A6B57},
+{0x50A6D10,0x50A6D1F},
+{0x50A6D78,0x50A6D7F},
+{0x50A6DD0,0x50A6DD7},
+{0x50A6EE0,0x50A6EEF},
+{0x50A6F08,0x50A6F0F},
+{0x50A6F38,0x50A6F3F},
+{0x50A7218,0x50A721B},
+{0x50A729F,0x50A729F},
+{0x50A7428,0x50A7437},
+{0x50A7460,0x50A746F},
+{0x50A7770,0x50A7777},
+{0x50A78E8,0x50A78EF},
+{0x50A7A08,0x50A7A0F},
+{0x50A7A3E,0x50A7A3E},
+{0x50A7AF0,0x50A7AF7},
+{0x53F1900,0x53F19FF},
+{0x5990044,0x5990047},
+{0x59900A0,0x59900AF},
+{0x5990450,0x5990457},
+{0x59904F7,0x59904F7},
+{0x59907FE,0x59907FE},
+{0x5990AB8,0x5990ABF},
+{0x5990B30,0x5990B37},
+{0x5990F88,0x5990F8F},
+{0x5991158,0x599115F},
+{0x59912A8,0x59912AB},
+{0x5991388,0x599138F},
+{0x5991418,0x599141B},
+{0x5991490,0x5991497},
+{0x59914F8,0x59914FF},
+{0x5C6FBA8,0x5C6FBAF},
+{0x5C7AE10,0x5C7AE27},
+{0x5C7AF08,0x5C7AF1F},
+{0x5C7AF70,0x5C7AF77},
+{0x5E03600,0x5E036FF},
+{0x5E13600,0x5E136FF},
 {0xE000000,0xE0007FF},
 {0xE000C00,0xE000FFF},
 {0xE010000,0xE0103FF},
@@ -71,6 +136,11 @@ ip_block_t china_ips[2560] = {
 {0x1B900000,0x1B90FFFF},
 {0x1B940000,0x1B9FFFFF},
 {0x1BB80000,0x1BE3FFFF},
+{0x1FC90004,0x1FC90007},
+{0x1FC90400,0x1FC904DF},
+{0x1FD68C80,0x1FD68CBF},
+{0x1FD69300,0x1FD693FF},
+{0x1FD69A00,0x1FD69AFF},
 {0x24000000,0x240003FF},
 {0x24000800,0x2401FFFF},
 {0x24040000,0x2407FFFF},
@@ -82,6 +152,39 @@ ip_block_t china_ips[2560] = {
 {0x24600000,0x24DFFFFF},
 {0x24F80000,0x24FBFFFF},
 {0x24FE0000,0x24FEFFFF},
+{0x253A4340,0x253A4347},
+{0x253A46A0,0x253A46BF},
+{0x253A46E8,0x253A46EB},
+{0x253A4A70,0x253A4A77},
+{0x253A4B30,0x253A4B37},
+{0x253A4D48,0x253A4D4F},
+{0x253A5426,0x253A5426},
+{0x253A54F0,0x253A54F7},
+{0x253A5780,0x253A5787},
+{0x253A5B44,0x253A5B47},
+{0x253A5B58,0x253A5B5F},
+{0x253A5D28,0x253A5D37},
+{0x253A5E78,0x253A5E7F},
+{0x253A5E81,0x253A5E81},
+{0x253A5EC0,0x253A5EC7},
+{0x253A5FF0,0x253A5FF7},
+{0x253A61EC,0x253A61EF},
+{0x253A6478,0x253A647F},
+{0x253A6A0C,0x253A6A0F},
+{0x253A6A20,0x253A6A37},
+{0x253A6A68,0x253A6A6B},
+{0x253A6AA0,0x253A6ABF},
+{0x253A6AE0,0x253A6AEB},
+{0x253A6E30,0x253A6E37},
+{0x253A7048,0x253A704F},
+{0x253A7440,0x253A7447},
+{0x253A7780,0x253A779F},
+{0x253A7980,0x253A7987},
+{0x253A7E48,0x253A7E4F},
+{0x253A7E80,0x253A7E87},
+{0x253A7FA0,0x253A7FA7},
+{0x25DE3600,0x25DE36FF},
+{0x25DF2D00,0x25DF2DFF},
 {0x27000000,0x270000FF},
 {0x27000200,0x2700FFFF},
 {0x27400000,0x275FFFFF},
@@ -114,6 +217,9 @@ ip_block_t china_ips[2560] = {
 {0x2AC90000,0x2AC97FFF},
 {0x2ACA0000,0x2AF0FFFF},
 {0x2AF20000,0x2AFFFFFF},
+{0x2E24C26F,0x2E24C278},
+{0x2E88BE00,0x2E88BEFF},
+{0x2EF81800,0x2EF819FF},
 {0x31040000,0x3107FFFF},
 {0x31330000,0x3137FFFF},
 {0x31400000,0x315FFFFF},
@@ -272,7 +378,8 @@ ip_block_t china_ips[2560] = {
 {0x4A5B1038,0x4A5B1047},
 {0x4A5B1060,0x4A5B1067},
 {0x4A5B10A0,0x4A5B10BF},
-{0x4A5B10E0,0x4A5B10F7},
+{0x4A5B10E0,0x4A5B10E7},
+{0x4A5B10F0,0x4A5B10F7},
 {0x4A5B1100,0x4A5B113F},
 {0x4A5B1190,0x4A5B1197},
 {0x4A5B11A0,0x4A5B11BF},
@@ -289,9 +396,10 @@ ip_block_t china_ips[2560] = {
 {0x4A5B1488,0x4A5B149F},
 {0x4A5B14C8,0x4A5B14D7},
 {0x4A5B14E8,0x4A5B14EF},
-{0x4A5B1700,0x4A5B1717},
+{0x4A5B1700,0x4A5B1707},
 {0x4A5B1720,0x4A5B173F},
-{0x4A5B1760,0x4A5B17AF},
+{0x4A5B1760,0x4A5B176F},
+{0x4A5B1778,0x4A5B17AF},
 {0x4A5B17B8,0x4A5B17DF},
 {0x4A5B1D00,0x4A5B1D07},
 {0x4A5B1D30,0x4A5B1D4F},
@@ -311,8 +419,27 @@ ip_block_t china_ips[2560] = {
 {0x4C48A8E8,0x4C48A8EF},
 {0x4C4AAEA0,0x4C4AAEA7},
 {0x4C4AAF20,0x4C4AAF2F},
+{0x4E18C950,0x4E18C95F},
+{0x4E18CA28,0x4E18CA2F},
+{0x4E18CB28,0x4E18CB2F},
+{0x4E18CE28,0x4E18CE2F},
+{0x515C7DF0,0x515C7DFF},
+{0x515F96A0,0x515F96BF},
+{0x515F9900,0x515F993F},
+{0x515F9AC0,0x515F9B1F},
+{0x54167F10,0x54167F17},
+{0x54C8C800,0x54C8C87F},
+{0x54C926C0,0x54C926FF},
+{0x55191BD1,0x55191BD1},
+{0x5519FE1D,0x5519FE1D},
+{0x5519FE21,0x5519FE22},
+{0x57FECE00,0x57FECFFF},
+{0x5BBEAD00,0x5BBEADFF},
 {0x5BC4E800,0x5BC4EBFF},
 {0x5BEA2400,0x5BEA24FF},
+{0x5F82C500,0x5F82C57F},
+{0x5F82C600,0x5F82C67F},
+{0x5F8F4828,0x5F8F482F},
 {0x627E8BC8,0x627E8BCF},
 {0x627EDD00,0x627EDEFF},
 {0x65000000,0x650003FF},
@@ -409,7 +536,9 @@ ip_block_t china_ips[2560] = {
 {0x670F6000,0x670F63FF},
 {0x670FC800,0x670FCBFF},
 {0x67103400,0x671037FF},
-{0x67105000,0x67105FFF},
+{0x67105000,0x67105BFF},
+{0x67106C00,0x67106FFF},
+{0x67107C00,0x67107FFF},
 {0x67140C00,0x67140FFF},
 {0x67142000,0x671423FF},
 {0x67147000,0x671473FF},
@@ -479,6 +608,7 @@ ip_block_t china_ips[2560] = {
 {0x6AE00000,0x6AEFFFFF},
 {0x6C3EB940,0x6C3EB97F},
 {0x6CAE4260,0x6CAE4277},
+{0x6DCD0B20,0x6DCD0B27},
 {0x6E060000,0x6E07FFFF},
 {0x6E100000,0x6E13FFFF},
 {0x6E280000,0x6E2BFFFF},
@@ -845,6 +975,8 @@ ip_block_t china_ips[2560] = {
 {0x7DD70000,0x7DD73FFF},
 {0x7DD80000,0x7DDFFFFF},
 {0x7DFE8000,0x7DFEFFFF},
+{0x80CC9120,0x80CC912F},
+{0x83E4BC00,0x83E4BDFF},
 {0x86C40000,0x86C4FFFF},
 {0x8B090000,0x8B09FFFF},
 {0x8B810000,0x8B81FFFF},
@@ -899,7 +1031,7 @@ ip_block_t china_ips[2560] = {
 {0x8E046000,0x8E04605F},
 {0x8E046080,0x8E0461FF},
 {0x8E046220,0x8E04626F},
-{0x8E046278,0x8E04627F},
+{0x8E046278,0x8E04629F},
 {0x8E0462C0,0x8E04633F},
 {0x8E046380,0x8E0463B7},
 {0x8E0463C0,0x8E0463DF},
@@ -915,10 +1047,10 @@ ip_block_t china_ips[2560] = {
 {0x8E046920,0x8E04693F},
 {0x8E046980,0x8E046A37},
 {0x8E046A50,0x8E046A57},
+{0x8E046A78,0x8E046A7F},
 {0x8E046AC0,0x8E046C8F},
 {0x8E046C98,0x8E046D0F},
-{0x8E046D20,0x8E046D5F},
-{0x8E046D68,0x8E046D7F},
+{0x8E046D20,0x8E046D7F},
 {0x8E046D90,0x8E046E07},
 {0x8E046E10,0x8E046F7F},
 {0x8E046FE0,0x8E04713F},
@@ -943,8 +1075,9 @@ ip_block_t china_ips[2560] = {
 {0x90340000,0x9034FFFF},
 {0x907B0000,0x907BFFFF},
 {0x90FF0000,0x90FFFFFF},
+{0x92F77A00,0x92F77A0F},
 {0x93F3D800,0x93F3D8FF},
-{0x93F3EC00,0x93F3ECFF},
+{0x93F3E000,0x93F3FFFF},
 {0x96000000,0x9600FFFF},
 {0x96730000,0x9673FFFF},
 {0x96790000,0x967AFFFF},
@@ -965,6 +1098,26 @@ ip_block_t china_ips[2560] = {
 {0x9D9C0000,0x9D9CFFFF},
 {0x9DFF0000,0x9DFFFFFF},
 {0x9FE20000,0x9FE2FFFF},
+{0x9FFD82D0,0x9FFD82DF},
+{0x9FFD86D8,0x9FFD86DF},
+{0x9FFD8724,0x9FFD8727},
+{0x9FFD8868,0x9FFD886F},
+{0x9FFD8960,0x9FFD8967},
+{0x9FFD89AC,0x9FFD89AF},
+{0x9FFD8B18,0x9FFD8B1F},
+{0x9FFD8BB8,0x9FFD8BBF},
+{0x9FFD8CA8,0x9FFD8CAB},
+{0x9FFD8DA0,0x9FFD8DA7},
+{0x9FFD8E50,0x9FFD8E57},
+{0x9FFD9078,0x9FFD907F},
+{0x9FFD9220,0x9FFD9227},
+{0x9FFD9280,0x9FFD929F},
+{0x9FFD9381,0x9FFD9381},
+{0x9FFD95F0,0x9FFD95F7},
+{0x9FFD9740,0x9FFD975F},
+{0x9FFD97A0,0x9FFD97A7},
+{0x9FFD9875,0x9FFD9875},
+{0xA03E0A00,0xA03E0AFF},
 {0xA1CF0000,0xA1CFFFFF},
 {0xA2690000,0xA269FFFF},
 {0xA3000000,0xA300FFFF},
@@ -973,7 +1126,6 @@ ip_block_t china_ips[2560] = {
 {0xA3B10000,0xA3B1FFFF},
 {0xA3B30000,0xA3B3FFFF},
 {0xA3CC0000,0xA3CCFFFF},
-{0xA63F06C8,0xA63F06CF},
 {0xA66F0000,0xA66FFFFF},
 {0xA78B0000,0xA78BFFFF},
 {0xA8A00000,0xA8A0FFFF},
@@ -1091,6 +1243,11 @@ ip_block_t china_ips[2560] = {
 {0xAFB20000,0xAFB2FFFF},
 {0xAFB88000,0xAFB8BFFF},
 {0xAFB90000,0xAFBFFFFF},
+{0xB212F640,0xB212F647},
+{0xB2A28B00,0xB2A28BFF},
+{0xB2AE1380,0xB2AE13FF},
+{0xB2AF86E8,0xB2AF86EF},
+{0xB2ECE204,0xB2ECE207},
 {0xB44C0000,0xB44FFFFF},
 {0xB4540000,0xB456FFFF},
 {0xB4580000,0xB45BFFFF},
@@ -1149,35 +1306,48 @@ ip_block_t china_ips[2560] = {
 {0xB7B80000,0xB7FFFFFF},
 {0xB85F2360,0xB85F237F},
 {0xB8ACB5F0,0xB8ACB5F7},
+{0xB9086810,0xB908683F},
+{0xB9086860,0xB9086867},
+{0xB9086880,0xB90868EF},
+{0xBC8A4F8E,0xBC8A4F8E},
+{0xBC8A4F94,0xBC8A4F94},
+{0xBC8A5376,0xBC8A5376},
+{0xBC8A78A9,0xBC8A78A9},
+{0xC0001100,0xC000111F},
 {0xC04AE030,0xC04AE03F},
 {0xC04AE060,0xC04AE07F},
 {0xC04AE090,0xC04AE0E7},
 {0xC04AE100,0xC04AE2BF},
-{0xC04AE300,0xC04AE45F},
-{0xC04AE500,0xC04AE6FF},
+{0xC04AE300,0xC04AE4EF},
+{0xC04AE4F8,0xC04AE707},
+{0xC04AE710,0xC04AE78F},
 {0xC04AE800,0xC04AE8BF},
 {0xC04AE900,0xC04AEABF},
 {0xC04AEAC8,0xC04AEADF},
 {0xC04AEAE8,0xC04AEAEF},
 {0xC04AEB00,0xC04AEB47},
-{0xC04AEB50,0xC04AEB7F},
-{0xC04AEC00,0xC04AEC3F},
+{0xC04AEB50,0xC04AEC3F},
 {0xC04AEC50,0xC04AED3F},
 {0xC04AED80,0xC04AEE8F},
 {0xC04AEE98,0xC04AEEC7},
 {0xC04AEED0,0xC04AEEDF},
-{0xC04AEEE8,0xC04AEEEF},
-{0xC04AEF00,0xC04AEF9F},
+{0xC04AEEE8,0xC04AEF9F},
 {0xC04AEFA8,0xC04AEFFF},
 {0xC04AF020,0xC04AF0E7},
 {0xC04AF0F0,0xC04AF19F},
-{0xC04AF1C0,0xC04AF27F},
-{0xC04AF288,0xC04AF29F},
-{0xC04AF300,0xC04AF3FF},
+{0xC04AF1A8,0xC04AF27F},
+{0xC04AF288,0xC04AF2BF},
+{0xC04AF300,0xC04AF45F},
+{0xC04AF468,0xC04AF46F},
+{0xC04AF500,0xC04AF55F},
+{0xC04AF600,0xC04AF63F},
+{0xC04AF648,0xC04AF6FF},
 {0xC04AF800,0xC04AF91F},
 {0xC04AF980,0xC04AFA1F},
-{0xC04AFA30,0xC04AFA7F},
-{0xC04AFC00,0xC04AFC0F},
+{0xC04AFA30,0xC04AFA87},
+{0xC04AFAC0,0xC04AFAFF},
+{0xC04AFC00,0xC04AFC17},
+{0xC04AFC40,0xC04AFCBF},
 {0xC04AFD00,0xC04AFE7F},
 {0xC04AFF00,0xC04AFFFF},
 {0xC07C9A00,0xC07C9AFF},
@@ -1185,6 +1355,32 @@ ip_block_t china_ips[2560] = {
 {0xC097FF00,0xC097FFFF},
 {0xC0A15C00,0xC0A15FFF},
 {0xC0BCAA00,0xC0BCAAFF},
+{0xC1DC7000,0xC1DC70FF},
+{0xC275652D,0xC275652D},
+{0xC2756537,0xC2756537},
+{0xC275672B,0xC275672B},
+{0xC275673A,0xC275673A},
+{0xC275674E,0xC275674F},
+{0xC2756778,0xC2756778},
+{0xC275677B,0xC275677B},
+{0xC2756796,0xC2756796},
+{0xC275679A,0xC275679B},
+{0xC27567B5,0xC27567B5},
+{0xC27567BD,0xC27567BD},
+{0xC27567C3,0xC27567C3},
+{0xC27567CE,0xC27567CE},
+{0xC27567D7,0xC27567D7},
+{0xC27567DA,0xC27567DB},
+{0xC27567E6,0xC27567E6},
+{0xC2757765,0xC2757765},
+{0xC370A714,0xC370A717},
+{0xC370A738,0xC370A73B},
+{0xC370A754,0xC370A757},
+{0xC370A79C,0xC370A7A3},
+{0xC370B114,0xC370B117},
+{0xC370B120,0xC370B123},
+{0xC370B17C,0xC370B17F},
+{0xC370BF0C,0xC370BF0C},
 {0xC60738C0,0xC60738CF},
 {0xC60F43F0,0xC60F43F7},
 {0xC60F4540,0xC60F457F},
@@ -1211,7 +1407,8 @@ ip_block_t china_ips[2560] = {
 {0xC6B13800,0xC6B1389F},
 {0xC6B138C0,0xC6B1397F},
 {0xC6B139A0,0xC6B13B27},
-{0xC6B13B30,0xC6B13DAF},
+{0xC6B13B30,0xC6B13C5F},
+{0xC6B13C80,0xC6B13DAF},
 {0xC6B13DC0,0xC6B13FFF},
 {0xC6F43500,0xC6F436FF},
 {0xC6F43B00,0xC6F43B3F},
@@ -2476,6 +2673,25 @@ ip_block_t china_ips[2560] = {
 {0xD3400000,0xD347FFFF},
 {0xD3500000,0xD367FFFF},
 {0xD3880000,0xD3A7FFFF},
+{0xD43FB51C,0xD43FB51F},
+{0xD43FB528,0xD43FB52F},
+{0xD43FB54C,0xD43FB54F},
+{0xD43FB58C,0xD43FB58F},
+{0xD43FB5B4,0xD43FB5BB},
+{0xD43FB5C8,0xD43FB5CB},
+{0xD43FB5E0,0xD43FB5E3},
+{0xD43FB704,0xD43FB704},
+{0xD43FB709,0xD43FB70A},
+{0xD43FB70F,0xD43FB70F},
+{0xD43FB713,0xD43FB713},
+{0xD43FB717,0xD43FB717},
+{0xD43FB71C,0xD43FB71C},
+{0xD43FB73A,0xD43FB73A},
+{0xD43FB73E,0xD43FB73E},
+{0xD43FB740,0xD43FB740},
+{0xD43FB744,0xD43FB744},
+{0xD43FB7D4,0xD43FB7DB},
+{0xD43FB7E4,0xD43FB7E7},
 {0xD80FEEA0,0xD80FEEBF},
 {0xD8263390,0xD8263393},
 {0xD826344C,0xD826344F},
@@ -2505,6 +2721,14 @@ ip_block_t china_ips[2560] = {
 {0xD8DAD6E0,0xD8DAD6E7},
 {0xD9078D00,0xD9078D27},
 {0xD9078D30,0xD9078F00},
+{0xD9086500,0xD90865FF},
+{0xD9ACB990,0xD9ACB990},
+{0xD9ACB9D7,0xD9ACB9D7},
+{0xD9ACB9D9,0xD9ACB9E2},
+{0xD9ACB9E6,0xD9ACB9E6},
+{0xD9ACB9E8,0xD9ACB9E8},
+{0xD9ACB9EB,0xD9ACB9ED},
+{0xD9ACB9EF,0xD9ACB9F0},
 {0xDA000000,0xDA1FFFFF},
 {0xDA380000,0xDA63FFFF},
 {0xDA645800,0xDA64FFFF},
